--[[------------------------------------------]]--
--[[--LostTreasures_Config.lua				--]]--
--[[------------------------------------------]]--
local options = {
	type = "group", 
	name = _LT.NAME, 
	args = {}, 
}

local resetWarning = "\n\nChanging this will reset all waypoints."

options.args.general = {
	type = "group", 
	name = _LT.NAME.." - ".._LT.VERSION, 
	args = {
		generalSettings = {
			type = "group", 
			order = 1, 
			name = "General Settings", 
			guiInline = true, 
			args = {
				enabled = {
					type = "toggle", 
					order = 1, 
					name = "Enable LostTreasures", 
					desc = "Toggles LostTreasures on or off.", 
					get = function()
						return _LT.SavedVars.ENABLED
					end, 
					set = function(_, value)
						_LT.SavedVars.ENABLED = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
--[[
				debug = {
					type = "toggle", 
					order = 2, 
					name = "Enable Debug", 
					desc = "This will show debug messages and change the way waypoints are displayed."..resetWarning, 
					get = function()
						return _LT.SavedVars.DEBUG
					end, 
					set = function(_, value)
						_LT.SavedVars.DEBUG = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
]]
				blockMiningPick = {
					type = "toggle", 
					order = 3, 
					name = "Hide \"Ancient Pandaren Mining Pick\" Waypoint", 
					desc = "This will allow you to hide the \"Ancient Pandaren Mining Pick\" from your waypoints.\n\nWill be removed once Blizzard fixes the quest flag.", 
					get = function()
						return _LT.SavedVars.BLOCK_MINING_PICK
					end, 
					set = function(_, value)
						_LT.SavedVars.BLOCK_MINING_PICK = value
						if ( _LT.SavedVars.BLOCK_MINING_PICK ) then
							LostTreasures:DoWaypoints({removeAll = false, addAll = false, removePoint = 31399})
						else
							LostTreasures:DoWaypoints({removeAll = false, addAll = false, addPoint = 31399})
						end
					end, 
				}, 
				generalText = {
					type = "description", 
					order = 10, 
					name = "\n\nThank you for choosing LostTreasures, a slim addon to help you find the lost treasures of Pandaria!\n\nAs with any other collection addon, be courteous of other players.\n\nIf you find any bugs or have any suggestions you can open a ticket at Curse! (links in README.html)\n\n", 
					width = "full", 
				}, 
			}, 
		}, 
		reloadWaypoints = {
			type = "execute", 
			order = 15, 
			name = "Reload Waypoints", 
			desc = "Reload all waypoints so you can begin a new trip.\n\nCommand to reload waypoints\n/lt reload", 
			func = function()
				LostTreasures:DoWaypoints({removeAll = true, addAll = true, setArrow = true, addPoint = 0, removePoint = 0})
			end, 
		}, 
		reloadUI = {
			type = "execute", 
			order = 16, 
			name = "Reload UI", 
			desc = "Reloads the Blizzard UI.", 
			func = function()
				ReloadUI()
			end, 
		}, 
		defaultSettings = {
			type = "execute", 
			order = 17, 
			name = "Default Settings", 
			desc = "This will restore all settings back to default.", 
			func = function()
				LostTreasures:DefaultSettings()
				LostTreasures:DoWaypoints()
			end, 
		}, 
	}, 
}

options.args.navigation = {
	type = "group", 
	name = _LT.NAME.." > Navigation Settings", 
	args = {
		navigationSettings = {
			type = "group", 
			order = 1, 
			name = "Configure TomTom for LostTreasures", 
			guiInline = true, 
			args = {
				useMinimap = {
					type = "toggle", 
					order = 1, 
					name = "Use Minimap", 
					desc = "This will show treasure waypoints on the minimap."..resetWarning, 
					get = function()
						return _LT.SavedVars.USE_MINIMAP
					end, 
					set = function(_, value)
						_LT.SavedVars.USE_MINIMAP = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				useWorldMap = {
					type = "toggle", 
					order = 2, 
					name = "Use World Map", 
					desc = "This will show treasure waypoints on the world map."..resetWarning, 
					get = function()
						return _LT.SavedVars.USE_WORLDMAP
					end, 
					set = function(_, value)
						_LT.SavedVars.USE_WORLDMAP = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				showAll = {
					type = "toggle", 
					order = 3, 
					name = "Show Looted Treasures", 
					desc = "This will show looted treasure waypoints. Useful if you want to help your friends hunt down treasures you have already found!"..resetWarning, 
					get = function()
						return _LT.SavedVars.SHOW_ALL_WAYPOINTS
					end, 
					set = function(_, value)
						_LT.SavedVars.SHOW_ALL_WAYPOINTS = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				showType = {
					type = "select", 
					order = 4, 
					name = "Show Treasures By Type", 
					desc = "Allows you to change what type of treasure waypoints are being shown.	\n\n|CFFFFD100All Treasures\n|CFFFFFFFFWill show both achievement and non-achievement related treasures.	\n\n|CFFFFD100Grey Treasures\n|CFFFFFFFFWill only show non-achievement related treasures.	\n\n|CFFFFD100Rare Treasures\n|CFFFFFFFFWill only show achievement related treasures."..resetWarning, 
					values = {
						[1] = "All Treasures", 
						[2] = "Grey Treasures", 
						[3] = "Rare Treasures", 
					}, 
					get = function()
						return _LT.SavedVars.SHOW_WAYPOINT_TYPE
					end, 
					set = function(_, value)
						_LT.SavedVars.SHOW_WAYPOINT_TYPE = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				arrowSettings = {
					type = "group", 
					order = 5, 
					name = "Arrow Settings", 
					guiInline = true, 
					args = {
						useArrow = {
							type = "toggle", 
							order = 1, 
							name = "Use TomTom Arrow", 
							desc = "This will have the TomTom arrow point to the closest waypoint.", 
							width = "double", 
							get = function()
								return _LT.SavedVars.USE_ARROW
							end, 
							set = function(_, value)
								_LT.SavedVars.USE_ARROW = value
								LostTreasures:DoWaypoints({removeAll = false, addAll = false})
							end, 
						}, 
						treasuresFirst = {
							type = "toggle", 
							order = 2, 
							name = "Point to Hidden Treasures First", 
							desc = "This will have the TomTom arrow point to the closest treasure waypoint (while one exists) before other waypoints.\n\nThis will also allow detailed information about waypoints in your chat box.", 
							width = "double", 
							get = function()
								return _LT.SavedVars.TREASURE_FIRST
							end, 
							set = function(_, value)
								_LT.SavedVars.TREASURE_FIRST = value
								LostTreasures:DoWaypoints({removeAll = false, addAll = false})
							end, 
						}, 
						printInfo = {
							type = "toggle", 
							order = 3, 
							name = "Show Detailed Information", 
							desc = "This will show detailed information about waypoints in your chat box.\n\nPoint to Hidden Treasures First must be enabled.", 
							disabled = function() return not _LT.SavedVars.TREASURE_FIRST end, 
							get = function()
								return _LT.SavedVars.SHOW_DETAILED_INFO
							end, 
							set = function(_, value)
								_LT.SavedVars.SHOW_DETAILED_INFO = value
								LostTreasures:DoWaypoints({removeAll = false, addAll = false})
							end, 
						}, 
						outsideZone = {
							type = "toggle", 
							order = 4, 
							name = "Allow closest waypoint to be outside current zone (TomTom Option)", 
							desc = "This will allow the TomTom arrow to point to waypoints outside of your current zone.\n\nPlease note that this will change the default setting for TomTom!\n\nYou can change this setting back here or in TomTom's options menu.\nGame Options (Esc) > Interface > AddOns > TomTom > Waypoint Arrow", 
							width = "double", 
							get = function()
								return TomTom.profile.arrow.closestusecontinent
							end, 
							set = function(_, value)
								TomTom.profile.arrow.closestusecontinent = value
								LostTreasures:DoWaypoints({removeAll = false, addAll = false})
							end, 
						}, 
					}, 
				}, 
				clearDistance = {
					type = "range", 
					order = 6, 
					name = "Waypoint Clear Distance", 
					desc = "This will allow you to change the distance from waypoint required in order for it to be removed.\n\nOff - 0\nDefault - 3\nMax - 10"..resetWarning, 
					width = "double", 
					min = 1, max = 10, step = 1, 
					get = function()
						return _LT.SavedVars.CLEARDISTANCE
					end, 
					set = function(_, value)
						_LT.SavedVars.CLEARDISTANCE = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
			}, 
		}, 
		reloadWaypoints = {
			type = "execute", 
			order = 15, 
			name = "Reload Waypoints", 
			desc = "Reload all waypoints so you can begin a new trip.\n\nCommand to reload waypoints\n/lt reload", 
			func = function()
				LostTreasures:DoWaypoints({removeAll = true, addAll = true, setArrow = true, addPoint = 0, removePoint = 0})
			end, 
		}, 
		reloadUI = {
			type = "execute", 
			order = 16, 
			name = "Reload UI", 
			desc = "Reloads the Blizzard UI.", 
			func = function()
				ReloadUI()
			end, 
		}, 
		defaultSettings = {
			type = "execute", 
			order = 17, 
			name = "Default Settings", 
			desc = "This will restore all settings back to default.", 
			func = function()
				LostTreasures:DefaultSettings()
				LostTreasures:DoWaypoints()
			end, 
		}, 
	}, 
}

AceConfigRegistry:RegisterOptionsTable("_LT_GeneralOptions", options.args.general)
AceConfigDialog:AddToBlizOptions("_LT_GeneralOptions", _LT.NAME)

AceConfigRegistry:RegisterOptionsTable("_LT_NavigationOptions", options.args.navigation)
AceConfigDialog:AddToBlizOptions("_LT_NavigationOptions", "Navigation Settings", _LT.NAME)